/*
 * Copyright © 2017 Red Hat Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Benjamin Otte <otte@gnome.org>
 */

#pragma once

#include <gtk/css/gtkcss.h>
#include "gtk/css/gtkcsstokenizerprivate.h"
#include "gtk/css/gtkcssparserprivate.h"
#include "gtkcssvalueprivate.h"

G_BEGIN_DECLS

GtkCssValue *   gtk_css_filter_value_new_none           (void);
GtkCssValue *   gtk_css_filter_value_parse              (GtkCssParser           *parser);

void            gtk_css_filter_value_push_snapshot      (const GtkCssValue      *filter,
                                                         GtkSnapshot            *snapshot);
void            gtk_css_filter_value_pop_snapshot       (const GtkCssValue      *filter,
                                                         GtkSnapshot            *snapshot);

G_END_DECLS

